@@ -28,8 +28,6 @@ class config:
     
     def get_logger(file=None):
 
-
-
         logger = logging.getLogger('logger_name')
 
         logger.setLevel(logging.INFO)
@@ -49,11 +47,12 @@ class config:
         if file:
 
             if not os.path.isdir('model_artefacts'):
-                os.mdir('model_artefacts')
+                
+                os.mkdir('model_artefacts')
 
             path = os.path.join('model_artefacts', file)
 
-            filehandler = logging.FileHandler(file)
+            filehandler = logging.FileHandler(path)
 
             filehandler.setLevel(logging.DEBUG)
 
