@@ -131,8 +131,10 @@ class binary_eda_plot:
     def plot_discrete(self, col, ax, target_index):
         
         data = self.data[self.data[self.target]==target_index]
+
+        data[col].value_counts().sort_index().plot(kind='bar', color=self.target_palette[target_index], ax=ax)
         
-        sns.countplot(x=col, data=data, ax=ax, color=self.target_palette[target_index])
+        #edsns.countplot(x=col, data=data, ax=ax, color=self.target_palette[target_index])
         
         plt.title(f'{col} : label = {target_index}')
         
