@@ -330,7 +330,7 @@ class xgb_training:
         for i in perf_diff_thresholds['thresholds']:
             
             precision, recall, f1_score, _ = metrics.precision_recall_fscore_support(
-                self.y_test, self.model_artefacts[self.model_name]['pred_prob'] > i, average='binary')
+                self.y_test, self.pred_prob > i, average='binary')
             
             perf_diff_thresholds['precision'].append(precision)
             
@@ -342,7 +342,7 @@ class xgb_training:
         
         self.log.info('Recall and precision calculation for different thresholds (test) completed')
         
-        self.model_artefacts[self.model_name]['df_diff_thresholds'] = perf_diff_thresholds
+        self.perf_diff_thresholds = perf_diff_thresholds
     
     def model_results(self):
         """
@@ -449,7 +449,7 @@ class xgb_training:
         
         palette = {0:'deeppink', 1:'green'}
         
-        df_pred = pd.DataFrame({'actual_class': self.y_test, 'pred_class': self.model_artefacts[self.model_name]['pred_class'], 'pred_prob': self.model_artefacts[self.model_name]['pred_prob']})
+        df_pred = pd.DataFrame({'actual_class': self.y_test, 'pred_class': self.pred_class, 'pred_prob': self.pred_prob})
         
         sns.kdeplot(data=df_pred, x='pred_prob', hue='pred_class', fill=True, legend=False, palette=palette, ax=ax)
         
